@@ -20,8 +20,9 @@ use {
         vote_state::{VoteInit, VoteState},
     },
     spl_stake_pool::{
-        find_stake_program_address, find_transient_stake_program_address, id, instruction,
-        processor,
+        find_deposit_authority_program_address, find_stake_program_address,
+        find_transient_stake_program_address, find_withdraw_authority_program_address, id,
+        instruction, processor,
         state::{self, FeeType, ValidatorList},
         MINIMUM_ACTIVE_STAKE,
     },
@@ -78,8 +79,11 @@ pub async fn create_mint(
         Some(&payer.pubkey()),
     );
     transaction.sign(&[payer, pool_mint], *recent_blockhash);
-    banks_client.process_transaction(transaction).await?;
-    Ok(())
+    #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+    banks_client
+        .process_transaction(transaction)
+        .await
+        .map_err(|e| e.into())
 }
 
 pub async fn transfer(
@@ -159,8 +163,11 @@ pub async fn create_token_account(
         Some(&payer.pubkey()),
     );
     transaction.sign(&[payer, account], *recent_blockhash);
-    banks_client.process_transaction(transaction).await?;
-    Ok(())
+    #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+    banks_client
+        .process_transaction(transaction)
+        .await
+        .map_err(|e| e.into())
 }
 
 pub async fn close_token_account(
@@ -183,8 +190,11 @@ pub async fn close_token_account(
         Some(&payer.pubkey()),
     );
     transaction.sign(&[payer, manager], *recent_blockhash);
-    banks_client.process_transaction(transaction).await?;
-    Ok(())
+    #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+    banks_client
+        .process_transaction(transaction)
+        .await
+        .map_err(|e| e.into())
 }
 
 pub async fn freeze_token_account(
@@ -207,8 +217,11 @@ pub async fn freeze_token_account(
         Some(&payer.pubkey()),
     );
     transaction.sign(&[payer, manager], *recent_blockhash);
-    banks_client.process_transaction(transaction).await?;
-    Ok(())
+    #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+    banks_client
+        .process_transaction(transaction)
+        .await
+        .map_err(|e| e.into())
 }
 
 pub async fn mint_tokens(
@@ -234,8 +247,11 @@ pub async fn mint_tokens(
         &[payer, mint_authority],
         *recent_blockhash,
     );
-    banks_client.process_transaction(transaction).await?;
-    Ok(())
+    #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+    banks_client
+        .process_transaction(transaction)
+        .await
+        .map_err(|e| e.into())
 }
 
 pub async fn burn_tokens(
@@ -261,8 +277,11 @@ pub async fn burn_tokens(
         &[payer, authority],
         *recent_blockhash,
     );
-    banks_client.process_transaction(transaction).await?;
-    Ok(())
+    #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+    banks_client
+        .process_transaction(transaction)
+        .await
+        .map_err(|e| e.into())
 }
 
 pub async fn get_token_balance(banks_client: &mut BanksClient, token: &Pubkey) -> u64 {
@@ -317,6 +336,7 @@ pub async fn create_stake_pool(
     pool_token_account: &Pubkey,
     manager: &Keypair,
     staker: &Pubkey,
+    withdraw_authority: &Pubkey,
     stake_deposit_authority: &Option<Keypair>,
     epoch_fee: &state::Fee,
     withdrawal_fee: &state::Fee,
@@ -353,6 +373,7 @@ pub async fn create_stake_pool(
                 &stake_pool.pubkey(),
                 &manager.pubkey(),
                 staker,
+                withdraw_authority,
                 &validator_list.pubkey(),
                 reserve_stake,
                 pool_mint,
@@ -385,8 +406,11 @@ pub async fn create_stake_pool(
         signers.push(stake_deposit_authority);
     }
     transaction.sign(&signers, *recent_blockhash);
-    banks_client.process_transaction(transaction).await?;
-    Ok(())
+    #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+    banks_client
+        .process_transaction(transaction)
+        .await
+        .map_err(|e| e.into())
 }
 
 pub async fn create_vote(
@@ -402,7 +426,7 @@ pub async fn create_vote(
     let mut instructions = vec![system_instruction::create_account(
         &payer.pubkey(),
         &validator.pubkey(),
-        42,
+        rent.minimum_balance(0),
         0,
         &system_program::id(),
     )];
@@ -624,14 +648,10 @@ impl StakePoolAccounts {
         let stake_pool = Keypair::new();
         let validator_list = Keypair::new();
         let stake_pool_address = &stake_pool.pubkey();
-        let (withdraw_authority, _) = Pubkey::find_program_address(
-            &[&stake_pool_address.to_bytes()[..32], b"withdraw"],
-            &id(),
-        );
-        let (stake_deposit_authority, _) = Pubkey::find_program_address(
-            &[&stake_pool_address.to_bytes()[..32], b"deposit"],
-            &id(),
-        );
+        let (stake_deposit_authority, _) =
+            find_deposit_authority_program_address(&id(), stake_pool_address);
+        let (withdraw_authority, _) =
+            find_withdraw_authority_program_address(&id(), stake_pool_address);
         let reserve_stake = Keypair::new();
         let pool_mint = Keypair::new();
         let pool_fee_account = Keypair::new();
@@ -700,13 +720,13 @@ impl StakePoolAccounts {
 
     pub async fn initialize_stake_pool(
         &self,
-        mut banks_client: &mut BanksClient,
+        banks_client: &mut BanksClient,
         payer: &Keypair,
         recent_blockhash: &Hash,
         reserve_lamports: u64,
     ) -> Result<(), TransportError> {
         create_mint(
-            &mut banks_client,
+            banks_client,
             payer,
             recent_blockhash,
             &self.pool_mint,
@@ -714,7 +734,7 @@ impl StakePoolAccounts {
         )
         .await?;
         create_token_account(
-            &mut banks_client,
+            banks_client,
             payer,
             recent_blockhash,
             &self.pool_fee_account,
@@ -723,7 +743,7 @@ impl StakePoolAccounts {
         )
         .await?;
         create_independent_stake_account(
-            &mut banks_client,
+            banks_client,
             payer,
             recent_blockhash,
             &self.reserve_stake,
@@ -736,7 +756,7 @@ impl StakePoolAccounts {
         )
         .await;
         create_stake_pool(
-            &mut banks_client,
+            banks_client,
             payer,
             recent_blockhash,
             &self.stake_pool,
@@ -746,6 +766,7 @@ impl StakePoolAccounts {
             &self.pool_fee_account.pubkey(),
             &self.manager,
             &self.staker.pubkey(),
+            &self.withdraw_authority,
             &self.stake_deposit_authority_keypair,
             &self.epoch_fee,
             &self.withdrawal_fee,
@@ -839,7 +860,12 @@ impl StakePoolAccounts {
             &signers,
             *recent_blockhash,
         );
-        banks_client.process_transaction(transaction).await.err()
+        #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+        banks_client
+            .process_transaction(transaction)
+            .await
+            .map_err(|e| e.into())
+            .err()
     }
 
     #[allow(clippy::too_many_arguments)]
@@ -890,7 +916,12 @@ impl StakePoolAccounts {
             &signers,
             *recent_blockhash,
         );
-        banks_client.process_transaction(transaction).await.err()
+        #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+        banks_client
+            .process_transaction(transaction)
+            .await
+            .map_err(|e| e.into())
+            .err()
     }
 
     #[allow(clippy::too_many_arguments)]
@@ -926,7 +957,12 @@ impl StakePoolAccounts {
             &[payer, user_transfer_authority],
             *recent_blockhash,
         );
-        banks_client.process_transaction(transaction).await.err()
+        #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+        banks_client
+            .process_transaction(transaction)
+            .await
+            .map_err(|e| e.into())
+            .err()
     }
 
     #[allow(clippy::too_many_arguments)]
@@ -978,7 +1014,12 @@ impl StakePoolAccounts {
             &signers,
             *recent_blockhash,
         );
-        banks_client.process_transaction(transaction).await.err()
+        #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+        banks_client
+            .process_transaction(transaction)
+            .await
+            .map_err(|e| e.into())
+            .err()
     }
 
     pub async fn get_validator_list(&self, banks_client: &mut BanksClient) -> ValidatorList {
@@ -1011,7 +1052,12 @@ impl StakePoolAccounts {
             &[payer],
             *recent_blockhash,
         );
-        banks_client.process_transaction(transaction).await.err()
+        #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+        banks_client
+            .process_transaction(transaction)
+            .await
+            .map_err(|e| e.into())
+            .err()
     }
 
     pub async fn update_stake_pool_balance(
@@ -1035,7 +1081,12 @@ impl StakePoolAccounts {
             &[payer],
             *recent_blockhash,
         );
-        banks_client.process_transaction(transaction).await.err()
+        #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+        banks_client
+            .process_transaction(transaction)
+            .await
+            .map_err(|e| e.into())
+            .err()
     }
 
     pub async fn cleanup_removed_validator_entries(
@@ -1054,7 +1105,12 @@ impl StakePoolAccounts {
             &[payer],
             *recent_blockhash,
         );
-        banks_client.process_transaction(transaction).await.err()
+        #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+        banks_client
+            .process_transaction(transaction)
+            .await
+            .map_err(|e| e.into())
+            .err()
     }
 
     pub async fn update_all(
@@ -1099,7 +1155,12 @@ impl StakePoolAccounts {
             &[payer],
             *recent_blockhash,
         );
-        banks_client.process_transaction(transaction).await.err()
+        #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+        banks_client
+            .process_transaction(transaction)
+            .await
+            .map_err(|e| e.into())
+            .err()
     }
 
     pub async fn add_validator_to_pool(
@@ -1125,7 +1186,12 @@ impl StakePoolAccounts {
             &[payer, &self.staker],
             *recent_blockhash,
         );
-        banks_client.process_transaction(transaction).await.err()
+        #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+        banks_client
+            .process_transaction(transaction)
+            .await
+            .map_err(|e| e.into())
+            .err()
     }
 
     #[allow(clippy::too_many_arguments)]
@@ -1164,7 +1230,12 @@ impl StakePoolAccounts {
             &[payer, &self.staker, destination_stake],
             *recent_blockhash,
         );
-        banks_client.process_transaction(transaction).await.err()
+        #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+        banks_client
+            .process_transaction(transaction)
+            .await
+            .map_err(|e| e.into())
+            .err()
     }
 
     #[allow(clippy::too_many_arguments)]
@@ -1194,7 +1265,12 @@ impl StakePoolAccounts {
             &[payer, &self.staker],
             *recent_blockhash,
         );
-        banks_client.process_transaction(transaction).await.err()
+        #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+        banks_client
+            .process_transaction(transaction)
+            .await
+            .map_err(|e| e.into())
+            .err()
     }
 
     #[allow(clippy::too_many_arguments)]
@@ -1225,7 +1301,12 @@ impl StakePoolAccounts {
             &[payer, &self.staker],
             *recent_blockhash,
         );
-        banks_client.process_transaction(transaction).await.err()
+        #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+        banks_client
+            .process_transaction(transaction)
+            .await
+            .map_err(|e| e.into())
+            .err()
     }
 
     pub async fn set_preferred_validator(
@@ -1249,7 +1330,12 @@ impl StakePoolAccounts {
             &[payer, &self.staker],
             *recent_blockhash,
         );
-        banks_client.process_transaction(transaction).await.err()
+        #[allow(clippy::useless_conversion)] // Remove during upgrade to 1.10
+        banks_client
+            .process_transaction(transaction)
+            .await
+            .map_err(|e| e.into())
+            .err()
     }
 }
 
